==> haskell-kan-extensions-5.2.7-6-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-kan-extensions.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 kan-extensions
version:              5.2.7
visibility:           public
id:                   kan-extensions-5.2.7-JfeWffDqtSLKUGtQLeDshe
key:                  kan-extensions-5.2.7-JfeWffDqtSLKUGtQLeDshe
license:              BSD-3-Clause
copyright:            Copyright (C) 2008-2016 Edward A. Kmett
maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            provisional
homepage:             http://github.com/ekmett/kan-extensions/
synopsis:
    Kan extensions, Kan lifts, the Yoneda lemma, and (co)density (co)monads

description:
    Kan extensions, Kan lifts, various forms of the Yoneda lemma, and (co)density (co)monads.

category:             Data Structures, Monads, Comonads, Functors
abi:                  67aeefb60a3f38a830ae43a7560fd91a
exposed:              True
exposed-modules:
    Control.Comonad.Density Control.Monad.Co Control.Monad.Codensity
    Data.Functor.Contravariant.Coyoneda Data.Functor.Contravariant.Day
    Data.Functor.Contravariant.Yoneda Data.Functor.Coyoneda
    Data.Functor.Day Data.Functor.Day.Curried
    Data.Functor.Invariant.Day Data.Functor.Kan.Lan
    Data.Functor.Kan.Ran Data.Functor.Yoneda

import-dirs:          /usr/lib/ghc-9.4.8/site-local/kan-extensions-5.2.7
library-dirs:         /usr/lib/ghc-9.4.8/site-local/kan-extensions-5.2.7
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/kan-extensions-5.2.7
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-kan-extensions
hs-libraries:         HSkan-extensions-5.2.7-JfeWffDqtSLKUGtQLeDshe
depends:
    adjunctions-4.4.3-GslgmzblhqqK8egLGUGYlj array-0.5.4.0
    base-4.17.2.1 comonad-5.0.9-I51Kpbi3BnaLUdzI5pNpo6 containers-0.6.7
    contravariant-1.5.5-p3peIMeiUA4Z37z2EtgYi
    distributive-0.6.2.1-CYwgdClE26GLAL3gsDf3Vu
    free-5.2-HTynOWv6dRn8Hu1n2x55wZ
    invariant-0.6.4-6eg25gf7jjOE81zABXGQ7I mtl-2.2.2
    profunctors-5.6.3-IpMnxIdCmTIm3BKwO5i76
    semigroupoids-6.0.1-Jr4qwSJRHF330Efi7HW1er
    tagged-0.8.9-KMS3sfDasKWItFZcxfaN6C transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-kan-extensions/html/kan-extensions.haddock

haddock-html:         /usr/share/doc/haskell-kan-extensions/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-kan-extensions-5.2.7-7-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-kan-extensions.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 kan-extensions
version:              5.2.7
visibility:           public
id:                   kan-extensions-5.2.7-B9wIar3Nw8l9Ec5H5xqQ8Y
key:                  kan-extensions-5.2.7-B9wIar3Nw8l9Ec5H5xqQ8Y
license:              BSD-3-Clause
copyright:            Copyright (C) 2008-2016 Edward A. Kmett
maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            provisional
homepage:             http://github.com/ekmett/kan-extensions/
synopsis:
    Kan extensions, Kan lifts, the Yoneda lemma, and (co)density (co)monads

description:
    Kan extensions, Kan lifts, various forms of the Yoneda lemma, and (co)density (co)monads.

category:             Data Structures, Monads, Comonads, Functors
abi:                  93730872293fdb5e9433ddbc634e6258
exposed:              True
exposed-modules:
    Control.Comonad.Density Control.Monad.Co Control.Monad.Codensity
    Data.Functor.Contravariant.Coyoneda Data.Functor.Contravariant.Day
    Data.Functor.Contravariant.Yoneda Data.Functor.Coyoneda
    Data.Functor.Day Data.Functor.Day.Curried
    Data.Functor.Invariant.Day Data.Functor.Kan.Lan
    Data.Functor.Kan.Ran Data.Functor.Yoneda

import-dirs:          /usr/lib/ghc-9.4.8/site-local/kan-extensions-5.2.7
library-dirs:         /usr/lib/ghc-9.4.8/site-local/kan-extensions-5.2.7
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/kan-extensions-5.2.7
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-kan-extensions
hs-libraries:         HSkan-extensions-5.2.7-B9wIar3Nw8l9Ec5H5xqQ8Y
depends:
    adjunctions-4.4.3-7LoYOA63sql9CKcJ2UCBn9 array-0.5.4.0
    base-4.17.2.1 comonad-5.0.9-KMCKZOfMqtjGKm0riXi643 containers-0.6.7
    contravariant-1.5.5-p3peIMeiUA4Z37z2EtgYi
    distributive-0.6.2.1-IRNu7pDowxUB62etqvswDi
    free-5.2-27x8ESBXKchDwiiT0BHGfN
    invariant-0.6.4-CO80mSdd0ycBFxUS9yblAP mtl-2.2.2
    profunctors-5.6.3-1rS3FBb1Nud9uOnEvo2O4l
    semigroupoids-6.0.1-EAROZ6BfD723cjjoHEcpI5
    tagged-0.8.9-KMS3sfDasKWItFZcxfaN6C transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-kan-extensions/html/kan-extensions.haddock

haddock-html:         /usr/share/doc/haskell-kan-extensions/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
